==> 2.1-Beta1.tar.gz: sharpdevelop/src/Main/ICSharpCode.SharpDevelop.Dom/Project/Src/Interfaces/IClass.cs <==
﻿// <file>
//     <copyright see="prj:///doc/copyright.txt"/>
//     <license see="prj:///doc/license.txt"/>
//     <owner name="Daniel Grunwald" email="daniel@danielgrunwald.de"/>
//     <version>$Revision$</version>
// </file>

using System;
using System.Collections;
using System.Collections.Generic;
using System.Reflection;

namespace ICSharpCode.SharpDevelop.Dom
{
	public interface IClass : IDecoration
	{
		string FullyQualifiedName {
			get;
			set;
		}
		
		/// <summary>
		/// The default return type to use for this class.
		/// </summary>
		IReturnType DefaultReturnType { get; }
		
		/// <summary>
		/// The fully qualified name in the internal .NET notation (with `1 for generic types)
		/// </summary>
		string DotNetName {
			get;
		}
		
		string Name {
			get;
		}

		string Namespace {
			get;
		}
		
		ClassType ClassType {
			get;
		}
		
		/// <summary>
		/// The project content in which this class is defined.
		/// </summary>
		IProjectContent ProjectContent {
			get;
		}
		
		ICompilationUnit CompilationUnit {
			get;
		}
		
		/// <summary>
		/// Region of the whole class including the body.
		/// </summary>
		DomRegion Region {
			get;
		}
		
		DomRegion BodyRegion {
			get;
		}
		
		List<IReturnType> BaseTypes {
			get;
		}
		
		/// <summary>Gets the class associated with the base type with the same index.</summary>
		IReturnType GetBaseType(int index);
		
		List<IClass> InnerClasses {
			get;
		}

		List<IField> Fields {
			get;
		}

		List<IProperty> Properties {
			get;
		}

		List<IMethod> Methods {
			get;
		}

		List<IEvent> Events {
			get;
		}
		
		IList<ITypeParameter> TypeParameters {
			get;
		}

		IEnumerable<IClass> ClassInheritanceTree {
			get;
		}
		
		IClass BaseClass {
			get;
		}
		
		IReturnType BaseType {
			get;
		}
		
		/// <summary>
		/// If this is a partial class, gets the compound class containing information from all parts.
		/// If this is not a partial class, a reference to this class is returned.
		/// </summary>
		IClass GetCompoundClass();
		
		IClass GetInnermostClass(int caretLine, int caretColumn);
		
		List<IClass> GetAccessibleTypes(IClass callingClass);
		
		/// <summary>
		/// Searches the member with the specified name. Returns the first member/overload found.
		/// </summary>
		IMember SearchMember(string memberName, LanguageProperties language);
		
		/// <summary>Return true if the specified class is a base class of this class; otherwise return false.</summary>
		/// <remarks>Returns false when possibleBaseClass is null.</remarks>
		bool IsTypeInInheritanceTree(IClass possibleBaseClass);
		
		bool HasPublicOrInternalStaticMembers {
			get;
		}
		bool HasExtensionMethods {
			get;
		}
	}
}

==> 3.0-Beta1.tar.gz: sharpdevelop/src/Main/ICSharpCode.SharpDevelop.Dom/Project/Src/Interfaces/IClass.cs <==
﻿// <file>
//     <copyright see="prj:///doc/copyright.txt"/>
//     <license see="prj:///doc/license.txt"/>
//     <owner name="Daniel Grunwald" email="daniel@danielgrunwald.de"/>
//     <version>$Revision$</version>
// </file>

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace ICSharpCode.SharpDevelop.Dom
{
	public interface IClass : IEntity
	{
		/// <summary>
		/// Region of the whole class including the body.
		/// </summary>
		DomRegion Region {
			get;
		}

		/// <summary>
		/// The default return type to use for this class.
		/// This property is mutable even when the IClass is frozen, see
		/// documentation for <see cref="HasCompoundClass"/>.
		/// This property is thread-safe.
		/// </summary>
		IReturnType DefaultReturnType { get; }
		
		ClassType ClassType {
			get;
		}
		
		/// <summary>
		/// The project content in which this class is defined.
		/// </summary>
		IProjectContent ProjectContent {
			get;
		}
		
		ICompilationUnit CompilationUnit {
			get;
		}
		
		IList<IReturnType> BaseTypes {
			get;
		}
		
		/// <summary>Gets the class associated with the base type with the same index.</summary>
		IReturnType GetBaseType(int index);
		
		IList<IClass> InnerClasses {
			get;
		}

		IList<IField> Fields {
			get;
		}

		IList<IProperty> Properties {
			get;
		}

		IList<IMethod> Methods {
			get;
		}

		IList<IEvent> Events {
			get;
		}
		
		IList<ITypeParameter> TypeParameters {
			get;
		}

		IEnumerable<IClass> ClassInheritanceTree {
			get;
		}
		
		IClass BaseClass {
			get;
		}
		
		IReturnType BaseType {
			get;
		}
		
		/// <summary>
		/// If this is a partial class, gets the compound class containing information from all parts.
		/// If this is not a partial class, a reference to this class is returned.
		/// </summary>
		IClass GetCompoundClass();
		
		IClass GetInnermostClass(int caretLine, int caretColumn);
		
		List<IClass> GetAccessibleTypes(IClass callingClass);
		
		/// <summary>
		/// Searches the member with the specified name. Returns the first member/overload found.
		/// </summary>
		IMember SearchMember(string memberName, LanguageProperties language);
		
		/// <summary>Return true if the specified class is a base class of this class; otherwise return false.</summary>
		/// <remarks>Returns false when possibleBaseClass is null.</remarks>
		bool IsTypeInInheritanceTree(IClass possibleBaseClass);
		
		bool HasPublicOrInternalStaticMembers {
			get;
		}
		bool HasExtensionMethods {
			get;
		}
		
		bool IsPartial {
			get;
		}
		
		/// <summary>
		/// Gets/sets if this class has an associated compound class.
		/// This property is mutable even if the IClass instance is frozen.
		/// This property is thread-safe.
		/// 
		/// This property may only be set by the IProjectContent implementation to which this class is added.
		/// 
		/// Rational: some languages support partial classes where only one of the parts needs
		/// the "partial" modifier. If the part without the modifier is added to the project
		/// content first, it is added without compound class and may get a DefaultReturnType that refers
		/// to itself.
		/// However, when the other part with the modifier is added, a compound class is created, and the
		/// DefaultReturnType of this class must change even though it is frozen.
		/// </summary>
		bool HasCompoundClass {
			get;
			set;
		}
		
		///// <summary>
		///// Creates a shallow copy of the class that is not frozen.
		///// </summary>
		//IClass Unfreeze();
	}
}
